#
# spec file for package java-jwt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Name:           java-jwt
Version:        4.4.0
Release:        1.2
Summary:        Java JWT
License:        MIT
Group:          Development/Libraries/Java
URL:            https://github.com/auth0/%{name}
Source0:        https://github.com/auth0/%{name}/archive/%{version}.tar.gz
Source1:        %{name}-build.xml
Source2:        https://repo1.maven.org/maven2/com/auth0/%{name}/%{version}/%{name}-%{version}.pom
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  jackson-annotations
BuildRequires:  jackson-core
BuildRequires:  jackson-databind
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
Java implementation of JSON Web Token (JWT)

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for the Logback library

%prep
%setup -q
cp %{SOURCE1} lib/build.xml

%build
mkdir -p lib/lib
build-jar-repository -s lib/lib jackson-annotations jackson-core jackson-databind
ant -f lib/build.xml jar javadoc

%install
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 lib/target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE2} %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

install -dm 0755 %{buildroot}%{_javadocdir}
cp -r lib/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Thu Oct 10 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.4.0
  * Main features of 4.x
    + Predicates based claim verification
    + Support for Instant API and Lambda functions
    + Improved Exceptions API
    + Consistent null handling
  * Breaking changes:
    + Make JWT constants final values
  * Security:
    + Bump com.fasterxml.jackson.core:jackson-databind to 2.13.4.2
    CVE-2022-42003
  * Additions:
    + Add integration with our Shipping orb
    + Add Ship CLI support
    + Provide straightforward example for JWKS
  * Changes:
    + Update to gradle 6.9.2
    + Update OSS plugin to latest
    + SDK-3466 Upgrade Codecov
    + Update README.md
    + Re-enable japicmp API diff checking
    + Update .shiprc to only update lib version in build.gradle
    + Optimise TokenUtils parsing
    + Update Circle Ship Orb configuration
    + Improve JWT parse/decode performance
    + Add support for passing json values for header and payload
    + Preserve insertion order for claims
    + Update Jackson to 2.14.2
  * Fixed
    + Check for null token before splitting
    + [SDK-3816] Update docs for verification thread-safety
    + Update Claim#asString documentation
    + Fix for exp claim considered valid if equal to now
- Build also module-info.java useful for modular javas
- Change the build system to ant. Upstream anyway uses gradle and
  ant is more flexible then maven for this case
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Thu Feb 27 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of java-jwt 3.8.3
